
# Type: prefix_reference


A URI associated with a given prefix

URI: [meta:prefix_reference](https://w3id.org/biolink/biolinkml/meta/prefix_reference)


## Domain and Range

[Prefix](Prefix.md) ->  <sub>REQ</sub> [Uri](types/Uri.md)

## Parents


## Children


## Used by

 * [Prefix](Prefix.md)
